@@ -41,8 +41,6 @@
 
 #define KPACKAGE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KPACKAGE_NO_DEPRECATED) && !defined(KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KPACKAGE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPACKAGE_NO_DEPRECATED
-#  define KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
 #endif
 #ifdef KPACKAGE_NO_DEPRECATED_WARNINGS
 #  define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPACKAGE_DEPRECATED_WARNINGS_SINCE KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0x56c00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KPACKAGE_DEPRECATED
-#  define KPACKAGE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KPACKAGE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KPACKAGE_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -133,6 +131,12 @@
 #else
 #  define KPACKAGE_DEPRECATED_VERSION_5_86(text)
 #endif
+
+#if KPACKAGE_DEPRECATED_WARNINGS_SINCE >= 0x56a00
+#  define KPACKAGE_DEPRECATED_VERSION_5_106(text) KPACKAGE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KPACKAGE_DEPRECATED_VERSION_5_106(text)
+#endif
 #define KPACKAGE_DEPRECATED_VERSION_5(minor, text)      KPACKAGE_DEPRECATED_VERSION_5_##minor(text)
 #define KPACKAGE_DEPRECATED_VERSION(major, minor, text) KPACKAGE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KPACKAGE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KPACKAGE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
